@@ -68,14 +68,14 @@ class CV2Camera:
         self._fps = 0.0
         #cv2.destroyAllWindows()
         pass
-    
+            
     def getCapture(self):
 
-        rtn = {"width":self._w,"heigh":self._h}
+        rtn = {"width":str(self._w),"heigh":str(self._h)}
         with self._lock:
             if not (self._img is None):
-                rtn["fps"] = self._fps
-                rtn["stram"] = str(base64.b64encode(self._img))
+                rtn["fps"] = str(self._fps)
+                rtn["stream"] = strfbytes(base64.b64encode(self._img))[2:-1]
             
         return rtn
         
